@@ -1,6 +1,6 @@
 package Test::Mojo::Role::TestDeep;
 # ABSTRACT: Add Test::Deep methods to Test::Mojo::WithRoles
-$Test::Mojo::Role::TestDeep::VERSION = '0.005';
+$Test::Mojo::Role::TestDeep::VERSION = '0.006';
 
 use strict;
 use warnings;
@@ -71,7 +71,7 @@ Test::Mojo::Role::TestDeep - Add Test::Deep methods to Test::Mojo::WithRoles
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -152,7 +152,7 @@ For example:
     # test.t
     $t->get_ok( 'test.html' )
       ->text_deeply(
-        'nav a' => [bag( Home Blog Projects )],
+        'nav a' => bag( qw( Home Blog Projects ) ),
         'nav element text is correct',
       );
 
@@ -162,7 +162,7 @@ This is equivalent to:
     my $dom = $t->tx->res->dom;
     cmp_deeply
         [ $dom->find( 'nav a' )->map( 'text' )->each ],
-        [ bag( Home Blog Projects ) ],
+        bag( qw( Home Blog Projects ) ),
         'nav element text is correct';
 
 =head2 attr_deeply
